==> MPlayer-0.90.tar.bz2: MPlayer-0.90/help/help_mp-ro.h <==
// Translated by:  Codre Adrian <codreadrian@softhome.net>

// ========================= MPlayer help ===========================

#ifdef HELP_MP_DEFINE_STATIC
static char* banner_text=
"\n\n"
"MPlayer " VERSION "(C) 2000-2001 Arpad Gereoffy (see DOCS!)\n"
"\n";

static char help_text[]=
"Folosire:   mplayer [opiuni] [cale/]fiier\n"
"\n"
"Opiuni:\n"
" -vo <drv[:disp]> Ieirea video: driver&dispozitiv ('-vo help' pentru o list)\n"
" -ao <drv[:disp]> Ieirea audio: driver&dispozitiv ('-ao help' pentru o list)\n"
" -vcd <numr pist>  folosete <pista> de pe dispozitivul VCD n loc de fiier\n"
#ifdef HAVE_LIBCSS
" -dvdauth <disp>  dispozitivul DVD pentru autentificare (la discuri encriptate)\n"
#endif
#ifdef USE_DVDREAD
" -dvd <titlu>  folosete titlu/pista de pe dispozitivul DVD n loc de fiier\n"
#endif
" -ss <poziia>   sare la poziia (secunde sau oo:mm:ss)\n"
" -nosound        fr sunet\n"
#ifdef USE_FAKE_MONO
" -stereo <mod>   modul stereo la MPEG (0:stereo 1:canalul stng 2:canalul drept)\n"
#endif
" -fs -vm -zoom   mod tot ecranul (tot ecranul,schimb modul,scalat prin software)\n"
" -x <x> -y <y>   scaleaz imaginea la <x> * <y> [dac driver-ul -vo suport!]\n"
" -sub <fiier>   specific fiierul cu subtitrri (vezi i -subfps, -subdelay)\n"
" -vid x -aid y   opiuni pentru selectarea pistei video (x) sau audio (y)\n"
" -fps x -srate y opiuni pentru schimbarea ratei video (x fps) sau audio (y Hz)\n"
" -pp <calitate>  activeaz filtrul de postprocesare (0-4 la DivX, 0-63 la MPEG)\n"
" -nobps          folosete metoda alternativ de sicronizare A-V (poate ajuta!)\n"
" -framedrop      activeaz sritul cadrelor (pentru calculatoare lente)\n"
"\n"
"Taste:\n"
" <-  sau  ->      caut fa/spate cu 10 secunde\n"
" sus sau jos      caut fa/spate cu 1 minut\n"
" p sau SPACE      pune filmul pe pauz (orice tast pentru a continua)\n"
" q sau ESC        oprete filmul i iese din program\n"
" + sau -          ajusteaz decalajul audio cu +/- 0.1 secunde\n"
" o                rotete modurile OSD: nimic / bar progres / bar progres+ceas\n"
" * sau /          crete sau scade volumul (apsai 'm' pentru principal/wav)\n"
" z sau x          ajusteaz decalajul subtitrrii cu +/- 0.1 secunde\n"
"\n"
" * * * VEDEI MANUALUL PENTRU DETALII,(ALTE) OPIUNI AVANSATE I TASTE ! * * *\n"
"\n";
#endif

// ========================= MPlayer messages ===========================

// mplayer.c: 

#define MSGTR_Exiting "\nIes... (%s)\n"
#define MSGTR_Exit_quit "Ieire"
#define MSGTR_Exit_eof "Sfritul fiierului"
#define MSGTR_Exit_error "Eroare fatal"
#define MSGTR_IntBySignal "\nMPlayer a fost intrerupt de semnalul %d n modulul: %s \n"
#define MSGTR_NoHomeDir "Nu gsesc directorul HOME\n"
#define MSGTR_GetpathProblem "get_path(\"config\") cu probleme\n"
#define MSGTR_CreatingCfgFile "Creez fiierul de configurare: %s\n"
#define MSGTR_InvalidVOdriver "Ieire video invalid: %s\nFolosii '-vo help' pentru o list de ieiri video disponibile.\n"
#define MSGTR_InvalidAOdriver "Ieire audio invalid: %s\nFolosii '-ao help' pentru o list de ieiri audio disponibile.\n"
#define MSGTR_CopyCodecsConf "(copiai etc/codecs.conf (din directorul surs MPlayer) n  ~/.mplayer/codecs.conf)\n"
#define MSGTR_CantLoadFont "Nu pot incrca fontul: %s\n"
#define MSGTR_CantLoadSub "Nu pot incarc subtitrarea: %s\n"
#define MSGTR_ErrorDVDkey "Eroare la procesarea cheii DVD.\n"
#define MSGTR_CmdlineDVDkey "Cheia DVD specificat n linia de comand este pstrat pentru decodificare.\n"
#define MSGTR_DVDauthOk "Secvena de autentificare DVD pare s fie OK.\n"
#define MSGTR_DumpSelectedStreamMissing "dump: FATALA: pista selectat lipsete!\n"
#define MSGTR_CantOpenDumpfile "Nu pot deschide fiierul (dump)!!!\n"
#define MSGTR_CoreDumped "core aruncat :)\n"
#define MSGTR_FPSnotspecified "FPS nespecificat (sau invalid) n antet! Folosii opiunea -fps!\n"
#define MSGTR_TryForceAudioFmt "ncerc s forez utilizarea unui codec audio din familia %d ...\n"
#define MSGTR_CantFindAfmtFallback "Nu pot s gsesc un codec audio pentru familia forat, revin la alte drivere.\n"
#define MSGTR_CantFindAudioCodec "Nu gsesc un codec audio pentru formatul 0x%X !\n"
#define MSGTR_TryUpgradeCodecsConfOrRTFM "*** ncercai s nnoii %s din etc/codecs.conf\n*** Dac nu ajut citii DOCS/CODECS!\n"
#define MSGTR_CouldntInitAudioCodec "Nu pot s iniializez codec-ul audio! -> fr sunet\n"
#define MSGTR_TryForceVideoFmt "ncerc s forez utilizarea unui codec video din familia %d ...\n"
#define MSGTR_CantFindVideoCodec "Nu gsesc un codec video pentru formatul 0x%X !\n"
#define MSGTR_VOincompCodec "mi pare ru, ieirea video selectat este incompatibil cu acest codec.\n"
#define MSGTR_CouldntInitVideoCodec "FATAL: Nu pot iniializa codec-ul video :(\n"
#define MSGTR_CannotInitVO "FATAL: Nu pot iniializa diver-ul video!\n"
#define MSGTR_CannotInitAO "nu pot deschide/iniializa dispozitivul audio -> fr sunet\n"
#define MSGTR_StartPlaying "ncep afiarea...\n"
#define MSGTR_SystemTooSlow "\n*******************************************************************************"\
			    "\n** Sistemul dumneavoastr este prea LENT ! ncercai cu -framedrop sau RTFM! **"\
			    "\n*******************************************************************************\n"

#define MSGTR_NoGui "MPlayer a fost compilat fr interfa grafic!\n"
#define MSGTR_GuiNeedsX "Interfaa grafica necesit X11!\n"
#define MSGTR_Playing "Afiez %s\n"
#define MSGTR_NoSound "Audio: fr sunet!!!\n"
#define MSGTR_FPSforced "FPS forat la %5.3f  (ftime: %5.3f)\n"

// open.c, stream.c:
#define MSGTR_CdDevNotfound "Dispozitivul CD-ROM '%s' nu a fost gsit!\n"
#define MSGTR_ErrTrackSelect "Eroare la selectarea pistei VCD!"
#define MSGTR_ReadSTDIN "Citesc de la intrarea standard...\n"
#define MSGTR_UnableOpenURL "Nu pot accesa adresa: %s\n"
#define MSGTR_ConnToServer "Conectat la serverul: %s\n"
#define MSGTR_FileNotFound "Fiier negsit: '%s'\n"

#define MSGTR_CantOpenDVD "Nu am putut deschide dispozitivul DVD: %s\n"
#define MSGTR_DVDwait "Citesc structura discului, v rog ateptai...\n"
#define MSGTR_DVDnumTitles "Pe acest DVD sunt %d titluri.\n"
#define MSGTR_DVDinvalidTitle "Numr titlu DVD invalid: %d\n"
#define MSGTR_DVDnumChapters "n acest titlu DVD sunt %d capitole.\n"
#define MSGTR_DVDinvalidChapter "Numr capitol DVD invalid: %d\n"
#define MSGTR_DVDnumAngles "Sunt %d unghiuri n acest titlu DVD.\n"
#define MSGTR_DVDinvalidAngle "Numr unghi DVD invalid: %d\n"
#define MSGTR_DVDnoIFO "Nu pot deschide fiierul IFO pentru titlul DVD %d.\n"
#define MSGTR_DVDnoVOBs "Nu pot deschide fiierul titlu (VTS_%02d_1.VOB).\n"
#define MSGTR_DVDopenOk "DVD deschis cu succes!\n"

// demuxer.c, demux_*.c:
#define MSGTR_AudioStreamRedefined "Atenie! Antet pist audio %d redefinit!\n"
#define MSGTR_VideoStreamRedefined "Atenie! Antet pist video %d redefinit!\n"
#define MSGTR_TooManyAudioInBuffer "\nDEMUXER: Prea multe (%d n %d bytes) pachete audio n tampon!\n"
#define MSGTR_TooManyVideoInBuffer "\nDEMUXER: Prea multe (%d n %d bytes) pachete video n tampon!\n"
#define MSGTR_MaybeNI "(poate afiai un film/pist ne-ntreesut sau codec-ul a dat eroare)\n"
#define MSGTR_Detected_XXX_FileFormat "Format fiier detectat: %s!\n"
#define MSGTR_InvalidMPEGES "Pist MPEG-ES invalid??? contactai autorul, poate fi un bug :(\n"
#define MSGTR_FormatNotRecognized "============= mi pare ru, acest format de fiier nu este recunoscut/suportat ===============\n"\
				  "======== Dac acest fiier este o pist AVI, ASF sau MPEG , contactai v rog autorul! ========\n"
#define MSGTR_MissingVideoStream "Nu am gsit piste video!\n"
#define MSGTR_MissingAudioStream "Nu am gsit piste audio...  -> fr sunet\n"
#define MSGTR_MissingVideoStreamBug "Lipsete pista video!? Contactai autorul, poate fi un bug :(\n"

#define MSGTR_DoesntContainSelectedStream "demux: fiierul nu conine pista audio sau video specificat\n"

#define MSGTR_NI_Forced "Forat"
#define MSGTR_NI_Detected "Detectat"
#define MSGTR_NI_Message "%s fiier AVI NE-NTREESUT!\n"

#define MSGTR_UsingNINI "Folosesc fiier AVI NE-NTREESUT eronat!\n"
#define MSGTR_CouldntDetFNo "Nu pot determina numrul de cadre (pentru cutare absolut)\n"
#define MSGTR_CantSeekRawAVI "Nu pot cuta n fiiere .AVI neindexate! (am nevoie de index, ncercai cu -idx!)  \n"
#define MSGTR_CantSeekFile "Nu pot cuta n fiier!  \n"

#define MSGTR_EncryptedVOB "Fiier VOB encriptat (necompilat cu suport libcss)! Citii fiierul DOCS/DVD\n"
#define MSGTR_EncryptedVOBauth "Fiier encriptat dar autentificarea nu a fost cerut de dumneavoastr.!!\n"

#define MSGTR_MOVcomprhdr "MOV: Antetele compresate nu sunt (nc) suportate!\n"
#define MSGTR_MOVvariableFourCC "MOV: Atenie! variabil FOURCC detectat!?\n"
#define MSGTR_MOVtooManyTrk "MOV: Atenie! prea multe piste!"

// dec_video.c & dec_audio.c:
#define MSGTR_CantOpenCodec "nu pot deschide codec-ul audio\n"
#define MSGTR_CantCloseCodec "nu pot deschide codec-ul video\n"

#define MSGTR_MissingDLLcodec "EROARE: Nu pot deschide codec-ul DirectShow necesar: %s\n"
#define MSGTR_ACMiniterror "Nu pot ncrca/iniializa codec-ul audio Win32/ACM (lipsete fiierul DLL?)\n"
#define MSGTR_MissingLAVCcodec "Nu gsesc codec-ul '%s' n libavcodec...\n"

#define MSGTR_MpegNoSequHdr "MPEG: FATAL: EOF n timpul cutrii antetului secvenei\n"
#define MSGTR_CannotReadMpegSequHdr "FATAL: Nu pot citi antetul secvenei!\n"
#define MSGTR_CannotReadMpegSequHdrEx "FATAL: Nu pot citi extensia antetului secvenei!\n"
#define MSGTR_BadMpegSequHdr "MPEG: Antet secven eronat!\n"
#define MSGTR_BadMpegSequHdrEx "MPEG: Extensie antet secven eronat!\n"

#define MSGTR_ShMemAllocFail "Nu pot aloca memoria partajat\n"
#define MSGTR_CantAllocAudioBuf "Nu pot aloca tamponul pentru ieirea audio\n"

#define MSGTR_UnknownAudio "Format audio necunoscut/lips, folosesc fr sunet\n"

// LIRC:
#define MSGTR_SettingUpLIRC "Setez suportul pentru LIRC...\n"
#define MSGTR_LIRCdisabled "Nu vei putea utiliza telecomanda\n"
#define MSGTR_LIRCopenfailed "Nu pot deschide suportul pentru LIRC!\n"
#define MSGTR_LIRCcfgerr "Nu pot citi fiierul de configurare LIRC %s !\n"


// ====================== GUI messages/buttons ========================

#ifdef HAVE_NEW_GUI

// --- labels ---
#define MSGTR_About "Despre..."
#define MSGTR_FileSelect "Selectare fiier..."
#define MSGTR_PlayList "List de redare..."
#define MSGTR_SkinBrowser "Navigator tematici..."

// --- buttons ---
#define MSGTR_Ok "Ok"
#define MSGTR_Cancel "Anulare"
#define MSGTR_Add "Adaug"
#define MSGTR_Remove "Scoate"

// --- error messages ---
#define MSGTR_NEMDB "mi pare ru, memorie insuficient pentru tamponul de desenare."
#define MSGTR_NEMFMR "mi pare ru, memorie insuficient pentru desenarea meniului."

// --- skin loader error messages
#define MSGTR_SKIN_ERRORMESSAGE "[tematic] eroare n fiierul de tematic la linia %d: %s" 
#define MSGTR_SKIN_WARNING1 "[tematic] eroare n fiierul de tematic la linia %d: component gasit dar nainte \"section\" negsit ( %s )"
#define MSGTR_SKIN_WARNING2 "[tematic] eroare n fiierul de tematic la linia %d: component gasit dar nainte \"subsection\" negsit (%s)"
#define MSGTR_SKIN_BITMAP_16bit  "adncimea de culoare de 16 bii sau mai puin pentru imagini nesuportat ( %s ).\n"
#define MSGTR_SKIN_BITMAP_FileNotFound  "fiier negsit ( %s )\n"
#define MSGTR_SKIN_BITMAP_BMPReadError "eroare la citire bmp ( %s )\n"
#define MSGTR_SKIN_BITMAP_TGAReadError "eroare la citire tga ( %s )\n"
#define MSGTR_SKIN_BITMAP_PNGReadError "eroare la citire png ( %s )\n"
#define MSGTR_SKIN_BITMAP_RLENotSupported "imagini tga mpachetate RLE nesuportate ( %s )\n"
#define MSGTR_SKIN_BITMAP_UnknownFileType "tip fiier necunoscut ( %s )\n"
#define MSGTR_SKIN_BITMAP_ConvertError "eroare la conversia de la 24 bii la 32 bii ( %s )\n"
#define MSGTR_SKIN_BITMAP_UnknownMessage "mesaj necunoscut: %s\n"
#define MSGTR_SKIN_FONT_NotEnoughtMemory "memorie insuficient\n"
#define MSGTR_SKIN_FONT_TooManyFontsDeclared "prea multe font-uri declarate\n"
#define MSGTR_SKIN_FONT_FontFileNotFound "fiier cu font negsit\n"
#define MSGTR_SKIN_FONT_FontImageNotFound "fiier imagine font negsit\n"
#define MSGTR_SKIN_FONT_NonExistentFontID "identificator font inexistent ( %s )\n"
#define MSGTR_SKIN_UnknownParameter "parametru necunoscut ( %s )\n"
#define MSGTR_SKINBROWSER_NotEnoughMemory "[Navigator tematici] memorie insuficient.\n"

#endif

==> MPlayer-1.0pre3.tar.bz2: MPlayer-1.0pre3/help/help_mp-ro.h <==
// Translated by:  Codre Adrian <codreadrian@softhome.net> (address bounces)

// ========================= MPlayer help ===========================

#ifdef HELP_MP_DEFINE_STATIC
static char help_text[]=
"Folosire:   mplayer [opiuni] [cale/]fiier\n"
"\n"
"Opiuni:\n"
" -vo <drv[:disp]> Ieirea video: driver&dispozitiv ('-vo help' pentru o list)\n"
" -ao <drv[:disp]> Ieirea audio: driver&dispozitiv ('-ao help' pentru o list)\n"
" vcd://<numr pist>  folosete <pista> de pe dispozitivul VCD n loc de fiier\n"
#ifdef USE_DVDREAD
" dvd://<titlu>  folosete titlu/pista de pe dispozitivul DVD n loc de fiier\n"
#endif
" -ss <poziia>   sare la poziia (secunde sau oo:mm:ss)\n"
" -nosound        fr sunet\n"
#ifdef USE_FAKE_MONO
" -stereo <mod>   modul stereo la MPEG (0:stereo 1:canalul stng 2:canalul drept)\n"
#endif
" -fs -vm -zoom   mod tot ecranul (tot ecranul,schimb modul,scalat prin software)\n"
" -x <x> -y <y>   scaleaz imaginea la <x> * <y> [dac driver-ul -vo suport!]\n"
" -sub <fiier>   specific fiierul cu subtitrri (vezi i -subfps, -subdelay)\n"
" -vid x -aid y   opiuni pentru selectarea pistei video (x) sau audio (y)\n"
" -fps x -srate y opiuni pentru schimbarea ratei video (x fps) sau audio (y Hz)\n"
" -pp <calitate>  activeaz filtrul de postprocesare (0-4 la DivX, 0-63 la MPEG)\n"
" -nobps          folosete metoda alternativ de sicronizare A-V (poate ajuta!)\n"
" -framedrop      activeaz sritul cadrelor (pentru calculatoare lente)\n"
"\n"
"Taste:\n"
" <-  sau  ->      caut fa/spate cu 10 secunde\n"
" sus sau jos      caut fa/spate cu 1 minut\n"
" p sau SPACE      pune filmul pe pauz (orice tast pentru a continua)\n"
" q sau ESC        oprete filmul i iese din program\n"
" + sau -          ajusteaz decalajul audio cu +/- 0.1 secunde\n"
" o                rotete modurile OSD: nimic / bar progres / bar progres+ceas\n"
" * sau /          crete sau scade volumul (apsai 'm' pentru principal/wav)\n"
" z sau x          ajusteaz decalajul subtitrrii cu +/- 0.1 secunde\n"
"\n"
" * * * VEDEI MANUALUL PENTRU DETALII,(ALTE) OPIUNI AVANSATE I TASTE! * * *\n"
"\n";
#endif

// ========================= MPlayer messages ===========================

// mplayer.c: 

#define MSGTR_Exiting "\nIes... (%s)\n"
#define MSGTR_Exit_quit "Ieire"
#define MSGTR_Exit_eof "Sfritul fiierului"
#define MSGTR_Exit_error "Eroare fatal"
#define MSGTR_IntBySignal "\nMPlayer a fost intrerupt de semnalul %d n modulul: %s \n"
#define MSGTR_NoHomeDir "Nu gsesc directorul HOME\n"
#define MSGTR_GetpathProblem "get_path(\"config\") cu probleme\n"
#define MSGTR_CreatingCfgFile "Creez fiierul de configurare: %s\n"
#define MSGTR_InvalidVOdriver "Ieire video invalid: %s\nFolosii '-vo help' pentru o list de ieiri video disponibile.\n"
#define MSGTR_InvalidAOdriver "Ieire audio invalid: %s\nFolosii '-ao help' pentru o list de ieiri audio disponibile.\n"
#define MSGTR_CopyCodecsConf "(copiai etc/codecs.conf (din directorul surs MPlayer) n  ~/.mplayer/codecs.conf)\n"
#define MSGTR_CantLoadFont "Nu pot incrca fontul: %s\n"
#define MSGTR_CantLoadSub "Nu pot incarc subtitrarea: %s\n"
#define MSGTR_ErrorDVDkey "Eroare la procesarea cheii DVD.\n"
#define MSGTR_CmdlineDVDkey "Cheia DVD specificat n linia de comand este pstrat pentru decodificare.\n"
#define MSGTR_DVDauthOk "Secvena de autentificare DVD pare s fie OK.\n"
#define MSGTR_DumpSelectedStreamMissing "dump: FATALA: pista selectat lipsete!\n"
#define MSGTR_CantOpenDumpfile "Nu pot deschide fiierul (dump)!!!\n"
#define MSGTR_CoreDumped "core aruncat :)\n"
#define MSGTR_FPSnotspecified "FPS nespecificat (sau invalid) n antet! Folosii opiunea -fps!\n"
#define MSGTR_TryForceAudioFmt "ncerc s forez utilizarea unui codec audio din familia %d...\n"
#define MSGTR_CantFindAfmtFallback "Nu pot s gsesc un codec audio pentru familia forat, revin la alte drivere.\n"
#define MSGTR_CantFindAudioCodec "Nu gsesc un codec audio pentru formatul 0x%X!\n"
#define MSGTR_CouldntInitAudioCodec "Nu pot s iniializez codec-ul audio! -> fr sunet\n"
#define MSGTR_TryForceVideoFmt "ncerc s forez utilizarea unui codec video din familia %d...\n"
#define MSGTR_CantFindVideoCodec "Nu gsesc un codec video pentru formatul 0x%X!\n"
#define MSGTR_VOincompCodec "mi pare ru, ieirea video selectat este incompatibil cu acest codec.\n"
#define MSGTR_CouldntInitVideoCodec "FATAL: Nu pot iniializa codec-ul video :(\n"
#define MSGTR_CannotInitVO "FATAL: Nu pot iniializa diver-ul video!\n"
#define MSGTR_CannotInitAO "nu pot deschide/iniializa dispozitivul audio -> fr sunet\n"
#define MSGTR_StartPlaying "ncep afiarea...\n"
#define MSGTR_SystemTooSlow "\n*******************************************************************************"\
			    "\n** Sistemul dumneavoastr este prea LENT! ncercai cu -framedrop sau RTFM! **"\
			    "\n*******************************************************************************\n"

#define MSGTR_NoGui "MPlayer a fost compilat fr interfa grafic!\n"
#define MSGTR_GuiNeedsX "Interfaa grafica necesit X11!\n"
#define MSGTR_Playing "Afiez %s\n"
#define MSGTR_NoSound "Audio: fr sunet!!!\n"
#define MSGTR_FPSforced "FPS forat la %5.3f  (ftime: %5.3f)\n"

// open.c, stream.c:
#define MSGTR_CdDevNotfound "Dispozitivul CD-ROM '%s' nu a fost gsit!\n"
#define MSGTR_ErrTrackSelect "Eroare la selectarea pistei VCD!"
#define MSGTR_ReadSTDIN "Citesc de la intrarea standard...\n"
#define MSGTR_UnableOpenURL "Nu pot accesa adresa: %s\n"
#define MSGTR_ConnToServer "Conectat la serverul: %s\n"
#define MSGTR_FileNotFound "Fiier negsit: '%s'\n"

#define MSGTR_CantOpenDVD "Nu am putut deschide dispozitivul DVD: %s\n"
#define MSGTR_DVDwait "Citesc structura discului, v rog ateptai...\n"
#define MSGTR_DVDnumTitles "Pe acest DVD sunt %d titluri.\n"
#define MSGTR_DVDinvalidTitle "Numr titlu DVD invalid: %d\n"
#define MSGTR_DVDnumChapters "n acest titlu DVD sunt %d capitole.\n"
#define MSGTR_DVDinvalidChapter "Numr capitol DVD invalid: %d\n"
#define MSGTR_DVDnumAngles "Sunt %d unghiuri n acest titlu DVD.\n"
#define MSGTR_DVDinvalidAngle "Numr unghi DVD invalid: %d\n"
#define MSGTR_DVDnoIFO "Nu pot deschide fiierul IFO pentru titlul DVD %d.\n"
#define MSGTR_DVDnoVOBs "Nu pot deschide fiierul titlu (VTS_%02d_1.VOB).\n"
#define MSGTR_DVDopenOk "DVD deschis cu succes!\n"

// demuxer.c, demux_*.c:
#define MSGTR_AudioStreamRedefined "Atenie! Antet pist audio %d redefinit!\n"
#define MSGTR_VideoStreamRedefined "Atenie! Antet pist video %d redefinit!\n"
#define MSGTR_TooManyAudioInBuffer "\nDEMUXER: Prea multe (%d n %d bytes) pachete audio n tampon!\n"
#define MSGTR_TooManyVideoInBuffer "\nDEMUXER: Prea multe (%d n %d bytes) pachete video n tampon!\n"
#define MSGTR_MaybeNI "(poate afiai un film/pist ne-ntreesut sau codec-ul a dat eroare)\n"
#define MSGTR_Detected_XXX_FileFormat "Format fiier detectat: %s!\n"
#define MSGTR_InvalidMPEGES "Pist MPEG-ES invalid??? contactai autorul, poate fi un bug :(\n"
#define MSGTR_FormatNotRecognized "============= mi pare ru, acest format de fiier nu este recunoscut/suportat ===============\n"\
				  "======== Dac acest fiier este o pist AVI, ASF sau MPEG , contactai v rog autorul! ========\n"
#define MSGTR_MissingVideoStream "Nu am gsit piste video!\n"
#define MSGTR_MissingAudioStream "Nu am gsit piste audio...  -> fr sunet\n"
#define MSGTR_MissingVideoStreamBug "Lipsete pista video!? Contactai autorul, poate fi un bug :(\n"

#define MSGTR_DoesntContainSelectedStream "demux: fiierul nu conine pista audio sau video specificat\n"

#define MSGTR_NI_Forced "Forat"
#define MSGTR_NI_Detected "Detectat"
#define MSGTR_NI_Message "%s fiier AVI NE-NTREESUT!\n"

#define MSGTR_UsingNINI "Folosesc fiier AVI NE-NTREESUT eronat!\n"
#define MSGTR_CouldntDetFNo "Nu pot determina numrul de cadre (pentru cutare absolut)\n"
#define MSGTR_CantSeekRawAVI "Nu pot cuta n fiiere .AVI neindexate! (am nevoie de index, ncercai cu -idx!)  \n"
#define MSGTR_CantSeekFile "Nu pot cuta n fiier!  \n"

#define MSGTR_MOVcomprhdr "MOV: Antetele compresate nu sunt (nc) suportate!\n"
#define MSGTR_MOVvariableFourCC "MOV: Atenie! variabil FOURCC detectat!?\n"
#define MSGTR_MOVtooManyTrk "MOV: Atenie! prea multe piste!"

// dec_video.c & dec_audio.c:
#define MSGTR_CantOpenCodec "nu pot deschide codec-ul audio\n"
#define MSGTR_CantCloseCodec "nu pot deschide codec-ul video\n"

#define MSGTR_MissingDLLcodec "EROARE: Nu pot deschide codec-ul DirectShow necesar: %s\n"
#define MSGTR_ACMiniterror "Nu pot ncrca/iniializa codec-ul audio Win32/ACM (lipsete fiierul DLL?)\n"
#define MSGTR_MissingLAVCcodec "Nu gsesc codec-ul '%s' n libavcodec...\n"

#define MSGTR_MpegNoSequHdr "MPEG: FATAL: EOF n timpul cutrii antetului secvenei\n"
#define MSGTR_CannotReadMpegSequHdr "FATAL: Nu pot citi antetul secvenei!\n"
#define MSGTR_CannotReadMpegSequHdrEx "FATAL: Nu pot citi extensia antetului secvenei!\n"
#define MSGTR_BadMpegSequHdr "MPEG: Antet secven eronat!\n"
#define MSGTR_BadMpegSequHdrEx "MPEG: Extensie antet secven eronat!\n"

#define MSGTR_ShMemAllocFail "Nu pot aloca memoria partajat\n"
#define MSGTR_CantAllocAudioBuf "Nu pot aloca tamponul pentru ieirea audio\n"

#define MSGTR_UnknownAudio "Format audio necunoscut/lips, folosesc fr sunet\n"

// LIRC:
#define MSGTR_SettingUpLIRC "Setez suportul pentru LIRC...\n"
#define MSGTR_LIRCdisabled "Nu vei putea utiliza telecomanda\n"
#define MSGTR_LIRCopenfailed "Nu pot deschide suportul pentru LIRC!\n"
#define MSGTR_LIRCcfgerr "Nu pot citi fiierul de configurare LIRC %s!\n"


// ====================== GUI messages/buttons ========================

#ifdef HAVE_NEW_GUI

// --- labels ---
#define MSGTR_About "Despre..."
#define MSGTR_FileSelect "Selectare fiier..."
#define MSGTR_PlayList "List de redare..."
#define MSGTR_SkinBrowser "Navigator tematici..."

// --- buttons ---
#define MSGTR_Ok "Ok"
#define MSGTR_Cancel "Anulare"
#define MSGTR_Add "Adaug"
#define MSGTR_Remove "Scoate"

// --- error messages ---
#define MSGTR_NEMDB "mi pare ru, memorie insuficient pentru tamponul de desenare."
#define MSGTR_NEMFMR "mi pare ru, memorie insuficient pentru desenarea meniului."

// --- skin loader error messages
#define MSGTR_SKIN_ERRORMESSAGE "[tematic] eroare n fiierul de tematic la linia %d: %s" 
#define MSGTR_SKIN_WARNING1 "[tematic] eroare n fiierul de tematic la linia %d: component gasit dar nainte \"section\" negsit (%s)"
#define MSGTR_SKIN_WARNING2 "[tematic] eroare n fiierul de tematic la linia %d: component gasit dar nainte \"subsection\" negsit (%s)"
#define MSGTR_SKIN_BITMAP_16bit  "adncimea de culoare de 16 bii sau mai puin pentru imagini nesuportat (%s).\n"
#define MSGTR_SKIN_BITMAP_FileNotFound  "fiier negsit (%s)\n"
#define MSGTR_SKIN_BITMAP_BMPReadError "eroare la citire BMP (%s)\n"
#define MSGTR_SKIN_BITMAP_TGAReadError "eroare la citire TGA (%s)\n"
#define MSGTR_SKIN_BITMAP_PNGReadError "eroare la citire PNG (%s)\n"
#define MSGTR_SKIN_BITMAP_RLENotSupported "imagini TGA mpachetate RLE nesuportate (%s)\n"
#define MSGTR_SKIN_BITMAP_UnknownFileType "tip fiier necunoscut (%s)\n"
#define MSGTR_SKIN_BITMAP_ConvertError "eroare la conversia de la 24 bii la 32 bii (%s)\n"
#define MSGTR_SKIN_BITMAP_UnknownMessage "mesaj necunoscut: %s\n"
#define MSGTR_SKIN_FONT_NotEnoughtMemory "memorie insuficient\n"
#define MSGTR_SKIN_FONT_TooManyFontsDeclared "prea multe font-uri declarate\n"
#define MSGTR_SKIN_FONT_FontFileNotFound "fiier cu font negsit\n"
#define MSGTR_SKIN_FONT_FontImageNotFound "fiier imagine font negsit\n"
#define MSGTR_SKIN_FONT_NonExistentFontID "identificator font inexistent (%s)\n"
#define MSGTR_SKIN_UnknownParameter "parametru necunoscut (%s)\n"
#define MSGTR_SKINBROWSER_NotEnoughMemory "[Navigator tematici] memorie insuficient.\n"

#endif
